summaryrefslogtreecommitdiffstats
path: root/knode/kncomposer.h
diff options
context:
space:
mode:
Diffstat (limited to 'knode/kncomposer.h')
-rw-r--r--knode/kncomposer.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/knode/kncomposer.h b/knode/kncomposer.h
index 83b406be..d4a4c2a8 100644
--- a/knode/kncomposer.h
+++ b/knode/kncomposer.h
@@ -255,7 +255,7 @@ class KNComposer::Editor : public KEdit {
TQ_OBJECT
public:
- Editor(KNComposer::ComposerView *_composerView, KNComposer *_composer, TQWidget *tqparent=0, char *name=0);
+ Editor(KNComposer::ComposerView *_composerView, KNComposer *_composer, TQWidget *parent=0, char *name=0);
~Editor();
TQStringList processedText();
@@ -308,7 +308,7 @@ class KNComposer::AttachmentView : public KListView {
TQ_OBJECT
public:
- AttachmentView(TQWidget *tqparent, char *name=0);
+ AttachmentView(TQWidget *parent, char *name=0);
~AttachmentView();
protected:
@@ -362,10 +362,10 @@ class KNLineEdit : public KABC::AddressLineEdit
typedef KABC::AddressLineEdit KNLineEditInherited;
public:
- KNLineEdit(KNComposer::ComposerView *_composerView, bool useCompletion, TQWidget *tqparent = 0,
+ KNLineEdit(KNComposer::ComposerView *_composerView, bool useCompletion, TQWidget *parent = 0,
const char *name = 0);
protected:
// Inherited. Always called by the tqparent when this widget is created.
virtual void loadAddresses();
void keyPressEvent(TQKeyEvent *e);
virtual TQPopupMenu *createPopupMenu();
@@ -380,7 +380,7 @@ class KNLineEditSpell : public KNLineEdit
Q_OBJECT
TQ_OBJECT
public:
- KNLineEditSpell(KNComposer::ComposerView *_composerView, bool useCompletion,TQWidget * tqparent, const char * name = 0);
+ KNLineEditSpell(KNComposer::ComposerView *_composerView, bool useCompletion,TQWidget * parent, const char * name = 0);
void highLightWord( unsigned int length, unsigned int pos );
void spellCheckDone( const TQString &s );
void spellCheckerMisspelling( const TQString &text, const TQStringList &, unsigned int pos);
@@ -362,10 +362,10 @@ class KNLineEdit : public KABC::AddressLineEdit
const char *name = 0);
protected:
- // Inherited. Always called by the tqparent when this widget is created.
+ // Inherited. Always called by the parent when this widget is created.
virtual void loadAddresses();
void keyPressEvent(TQKeyEvent *e);